/*
 * wpgraphicsmenu.cpp
 *
 *  Created on: 18.5.2010
 *      Author: jlep
 */

#include "wpstatusbargraphicswidget.h"

#include <QGraphicsSceneMouseEvent>

#ifdef Q_WS_MAEMO_5
    #include <QDBusConnection>
    #include <QDBusMessage>
#endif

WPTitleBarGraphicsWidget::WPTitleBarGraphicsWidget(BlogView& aBlogView, QGraphicsWidget* aParent, QGraphicsScene& aScene, BusyIndicator* aIndicator) :
    QGraphicsWidget(aParent), 
    iBlogView(aBlogView), 
    iScene(aScene), 
    iText(tr("")), 
    iIndicator(*aIndicator), 
    iPicWidth(0),
    iMenuIcon(":/images/menu_icon.png"),
    iMenuIconActive(false)
{
    setFocusPolicy(Qt::StrongFocus);

    setMinimumHeight(StatusBarHeight);
    setMaximumHeight(StatusBarHeight);

    // total horizontal space taken up by icons
    iPicWidth = 0;
    
#ifdef Q_WS_MAEMO_5
    // expose button
    iPicWidth += 5 + iMenuIcon.width() + 5;
#endif

    // text spacing
    iPicWidth += 5;

    // busy indicator
    iPicWidth += 5 + iIndicator.PixmapToDraw().width();

    // update when busy indicator changes
    connect(aIndicator, SIGNAL(changed()), this, SLOT(update()));
}

WPTitleBarGraphicsWidget::~WPTitleBarGraphicsWidget()
{

}

void WPTitleBarGraphicsWidget::SetText(const QString& aText)
{
    iText = aText;
    update();
}

void WPTitleBarGraphicsWidget::mousePressEvent (QGraphicsSceneMouseEvent *event)
{
    qDebug("WPTitleBarGraphicsWidget::mousePressEvent");

#ifdef Q_WS_MAEMO_5
    if (event->pos().x() <= 5 + iMenuIcon.width() + 5) {
        // update overlay
        iMenuIconActive = true;
        update();
    }
#else
    // unused
    (void) event;

#endif
}

void WPTitleBarGraphicsWidget::mouseReleaseEvent (QGraphicsSceneMouseEvent *event)
{
    qDebug("WPTitleBarGraphicsWidget::mouseReleaseEvent");

#ifdef Q_WS_MAEMO_5
    if (iMenuIconActive) {
        // clear overlay
        iMenuIconActive = false;
        update();
        
        // trigger        
        ShowExpose();
    }
#else
    // unused
    (void) event;

#endif    
}

#ifdef Q_WS_MAEMO_5
void WPTitleBarGraphicsWidget::ShowExpose()
{
    QDBusConnection connection = QDBusConnection::sessionBus();
    QDBusMessage message = QDBusMessage::createSignal("/", "com.nokia.hildon_desktop", "exit_app_view");

    connection.send(message);
}
#endif

void WPTitleBarGraphicsWidget::update ()
{
    QGraphicsWidget::update();
}

void WPTitleBarGraphicsWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem*/*option*/, QWidget*/*widget*/)
{
    const QColor textColor = QColor(236,236,236);
    const QColor lineColor = QColor(80,80,80);
    const QColor bgColor = QColor(112,112,112);
    
    painter->setBrush(bgColor);
    painter->setPen(Qt::NoPen);
    painter->drawRect(boundingRect());

    int x = 5;
    int y = 0;

#ifdef Q_WS_MAEMO_5
    // centered
    y = (StatusBarHeight - iMenuIcon.height()) / 2;

    // menu icon
    painter->drawPixmap(x, y, iMenuIcon);

    if (iMenuIconActive) {
        painter->setPen(Qt::NoPen);
        painter->setBrush(QColor(255, 255, 255, 128));
        painter->drawRect(0, 0, x + iMenuIcon.width() + 5, StatusBarHeight);
    }
    
    // icon + spacing
    x += iMenuIcon.width() + 5;

    // spacing
    painter->setPen(lineColor);
    painter->drawLine(x, 0, x, StatusBarHeight - 0);

    // text spacing
    x += 5;
#endif

    // title
    QFont &font = *iBlogView.GetThemeData().iStatusBarFont;
    QFontMetrics titleFm(font);
    
    int width = int(boundingRect().width() - iPicWidth);
    iElidedText = titleFm.elidedText(iText, Qt::ElideRight, width);

    painter->setFont(font);
    painter->setPen(textColor);
    painter->drawText(QRect(x, 0, width, StatusBarHeight), Qt::AlignVCenter, iElidedText);

    // busy indicator
    if (iIndicator.IsActive()) {
        QPixmap &frame = iIndicator.PixmapToDraw();
        
        x = int(boundingRect().width() - frame.width());
        y = (StatusBarHeight - frame.height()) / 2;

        painter->drawPixmap(x, y, frame);
    }
}

